# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/clients/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/clients/address.proto\x12#pro.omni.oms.api.v1.clients.address\x1a\x11\x63ommon/base.proto"?\n\x0fTerritoryMatrix\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05"\xbf\x02\n\x07\x41\x64\x64ress\x12\x12\n\ncountry_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0ctype_address\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x0f\n\x07street2\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\t\x12\x0b\n\x03lng\x18\x08 \x01(\t\x12\x10\n\x08zip_code\x18\t \x01(\t\x12P\n\x12territory_matrixes\x18\n \x03(\x0b\x32\x34.pro.omni.oms.api.v1.clients.address.TerritoryMatrix\x12\x0e\n\x06\x61\x63tive\x18\x0b \x01(\x08\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc6\x02\n\x14\x41\x64\x64ressCreateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x12\n\ncountry_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0ctype_address\x18\x05 \x01(\t\x12\x0e\n\x06street\x18\x06 \x01(\t\x12\x0f\n\x07street2\x18\x07 \x01(\t\x12\x0b\n\x03lat\x18\x08 \x01(\t\x12\x0b\n\x03lng\x18\t \x01(\t\x12\x10\n\x08zip_code\x18\n \x01(\t\x12P\n\x12territory_matrixes\x18\x0b \x03(\x0b\x32\x34.pro.omni.oms.api.v1.clients.address.TerritoryMatrix\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"\xa0\x01\n\x14\x41\x64\x64ressUpdateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"o\n\x14\x41\x64\x64ressDeleteRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x41\x64\x64ressDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xb3\x03\n\x10\x41\x64\x64ressesService\x12\x88\x01\n\rAddressCreate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressCreateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressCreateResponse"\x00\x12\x88\x01\n\rAddressUpdate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressUpdateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressUpdateResponse"\x00\x12\x88\x01\n\rAddressDelete\x12\x39.pro.omni.oms.api.v1.clients.address.AddressDeleteRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.clients.address_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _TERRITORYMATRIX._serialized_start = 84
    _TERRITORYMATRIX._serialized_end = 147
    _ADDRESS._serialized_start = 150
    _ADDRESS._serialized_end = 469
    _ADDRESSCREATEREQUEST._serialized_start = 472
    _ADDRESSCREATEREQUEST._serialized_end = 798
    _ADDRESSCREATERESPONSE._serialized_start = 801
    _ADDRESSCREATERESPONSE._serialized_end = 962
    _ADDRESSUPDATEREQUEST._serialized_start = 965
    _ADDRESSUPDATEREQUEST._serialized_end = 1125
    _ADDRESSUPDATERESPONSE._serialized_start = 1128
    _ADDRESSUPDATERESPONSE._serialized_end = 1289
    _ADDRESSDELETEREQUEST._serialized_start = 1291
    _ADDRESSDELETEREQUEST._serialized_end = 1402
    _ADDRESSDELETERESPONSE._serialized_start = 1404
    _ADDRESSDELETERESPONSE._serialized_end = 1502
    _ADDRESSESSERVICE._serialized_start = 1505
    _ADDRESSESSERVICE._serialized_end = 1940
# @@protoc_insertion_point(module_scope)
