# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_price_pb2 as v1_dot_rules_dot_delivery__price__pb2


class DeliveryPriceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryPriceCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceCreate",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.FromString,
        )
        self.DeliveryPriceRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceRead",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.FromString,
        )
        self.DeliveryPriceUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceUpdate",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.FromString,
        )
        self.DeliveryPriceDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceDelete",
            request_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.FromString,
        )


class DeliveryPriceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryPriceCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryPriceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryPriceCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceCreate,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.SerializeToString,
        ),
        "DeliveryPriceRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceRead,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.SerializeToString,
        ),
        "DeliveryPriceUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.SerializeToString,
        ),
        "DeliveryPriceDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDelete,
            request_deserializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryPriceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryPriceCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceCreate",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceRead",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceUpdate",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceService/DeliveryPriceDelete",
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__pb2.DeliveryPriceDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
