# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/picking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/stock/picking.proto\x12!pro.omni.oms.api.v1.stock.picking\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xa2\x01\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0buser_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb1\x01\n\nAttachment\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64oc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9e\x01\n\x07\x43\x61rrier\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xac\x01\n\x10ProcurementGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmove_type\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xab\x05\n\x07Picking\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x03 \x01(\x05\x12\x13\n\x0blocation_id\x18\x04 \x01(\x05\x12\x18\n\x10location_dest_id\x18\x05 \x01(\x05\x12\x0f\n\x07user_id\x18\x06 \x01(\x05\x12\x1b\n\x13\x61ttachment_guide_id\x18\x07 \x01(\x05\x12\x1d\n\x15\x61ttachment_invoice_id\x18\x08 \x01(\x05\x12\x0e\n\x06origin\x18\t \x01(\t\x12:\n\x16\x64\x61te_start_preparation\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdate_done\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0escheduled_date\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16time_total_preparation\x18\r \x01(\x02\x12\x15\n\rtime_assigned\x18\x0e \x01(\x02\x12\x12\n\ncarrier_id\x18\x0f \x01(\x05\x12\x31\n\rdate_delivery\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14\x63\x61rrier_tracking_ref\x18\x11 \x01(\t\x12\x10\n\x08group_id\x18\x12 \x01(\x05\x12\x0e\n\x06weight\x18\x13 \x01(\x02\x12\x17\n\x0fshipping_weight\x18\x14 \x01(\x02\x12*\n\x06\x61\x63tive\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x16 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"n\n\x11UserCreateRequest\x12\x13\n\x0buser_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x12UserCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x04user\x18\x02 \x01(\x0b\x32\'.pro.omni.oms.api.v1.stock.picking.User"\xed\x02\n\x0fUserReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd0\x01\n\x10UserReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x05users\x18\x03 \x03(\x0b\x32\'.pro.omni.oms.api.v1.stock.picking.User"\x82\x01\n\x11UserUpdateRequest\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32\'.pro.omni.oms.api.v1.stock.picking.User\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x01\n\x12UserUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x04user\x18\x02 \x01(\x0b\x32\'.pro.omni.oms.api.v1.stock.picking.User"W\n\x11UserDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12UserDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"}\n\x17\x41ttachmentCreateRequest\x12\x0e\n\x06\x64oc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa8\x01\n\x18\x41ttachmentCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\nattachment\x18\x02 \x01(\x0b\x32-.pro.omni.oms.api.v1.stock.picking.Attachment"\xf3\x02\n\x15\x41ttachmentReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe2\x01\n\x16\x41ttachmentReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x42\n\x0b\x61ttachments\x18\x03 \x03(\x0b\x32-.pro.omni.oms.api.v1.stock.picking.Attachment"\x94\x01\n\x17\x41ttachmentUpdateRequest\x12\x41\n\nattachment\x18\x01 \x01(\x0b\x32-.pro.omni.oms.api.v1.stock.picking.Attachment\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa8\x01\n\x18\x41ttachmentUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\nattachment\x18\x02 \x01(\x0b\x32-.pro.omni.oms.api.v1.stock.picking.Attachment"]\n\x17\x41ttachmentDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"e\n\x18\x41ttachmentDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"j\n\x14\x43\x61rrierCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43\x61rrierCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63\x61rrier\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Carrier"\xf0\x02\n\x12\x43\x61rrierReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13\x43\x61rrierReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08\x63\x61rriers\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Carrier"\x8b\x01\n\x14\x43\x61rrierUpdateRequest\x12;\n\x07\x63\x61rrier\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Carrier\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43\x61rrierUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63\x61rrier\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Carrier"Z\n\x14\x43\x61rrierDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43\x61rrierDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"x\n\x1dProcurementGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmove_type\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbb\x01\n\x1eProcurementGroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12N\n\x11procurement_group\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.ProcurementGroup"\xf9\x02\n\x1bProcurementGroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf5\x01\n\x1cProcurementGroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12O\n\x12procurement_groups\x18\x03 \x03(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.ProcurementGroup"\xa7\x01\n\x1dProcurementGroupUpdateRequest\x12N\n\x11procurement_group\x18\x01 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.ProcurementGroup\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbb\x01\n\x1eProcurementGroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12N\n\x11procurement_group\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.ProcurementGroup"c\n\x1dProcurementGroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1eProcurementGroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf7\x04\n\x14PickingCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fpicking_type_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x18\n\x10location_dest_id\x18\x04 \x01(\x05\x12\x0f\n\x07user_id\x18\x05 \x01(\x05\x12\x1b\n\x13\x61ttachment_guide_id\x18\x06 \x01(\x05\x12\x1d\n\x15\x61ttachment_invoice_id\x18\x07 \x01(\x05\x12\x0e\n\x06origin\x18\x08 \x01(\t\x12:\n\x16\x64\x61te_start_preparation\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tdate_done\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0escheduled_date\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16time_total_preparation\x18\x0c \x01(\x02\x12\x15\n\rtime_assigned\x18\r \x01(\x02\x12\x12\n\ncarrier_id\x18\x0e \x01(\x05\x12\x31\n\rdate_delivery\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14\x63\x61rrier_tracking_ref\x18\x10 \x01(\t\x12\x10\n\x08group_id\x18\x11 \x01(\x05\x12\x0e\n\x06weight\x18\x12 \x01(\x02\x12\x17\n\x0fshipping_weight\x18\x13 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x14 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"\xf0\x02\n\x12PickingReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13PickingReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08pickings\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"\x8b\x01\n\x14PickingUpdateRequest\x12;\n\x07picking\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking"Z\n\x14PickingDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15PickingDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe4\x15\n\x0ePickingService\x12\x84\x01\n\rPickingCreate\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingCreateResponse"\x00\x12~\n\x0bPickingRead\x12\x35.pro.omni.oms.api.v1.stock.picking.PickingReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.picking.PickingReadResponse"\x00\x12\x84\x01\n\rPickingUpdate\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingUpdateResponse"\x00\x12\x84\x01\n\rPickingDelete\x12\x37.pro.omni.oms.api.v1.stock.picking.PickingDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.PickingDeleteResponse"\x00\x12{\n\nUserCreate\x12\x34.pro.omni.oms.api.v1.stock.picking.UserCreateRequest\x1a\x35.pro.omni.oms.api.v1.stock.picking.UserCreateResponse"\x00\x12u\n\x08UserRead\x12\x32.pro.omni.oms.api.v1.stock.picking.UserReadRequest\x1a\x33.pro.omni.oms.api.v1.stock.picking.UserReadResponse"\x00\x12{\n\nUserUpdate\x12\x34.pro.omni.oms.api.v1.stock.picking.UserUpdateRequest\x1a\x35.pro.omni.oms.api.v1.stock.picking.UserUpdateResponse"\x00\x12{\n\nUserDelete\x12\x34.pro.omni.oms.api.v1.stock.picking.UserDeleteRequest\x1a\x35.pro.omni.oms.api.v1.stock.picking.UserDeleteResponse"\x00\x12\x8d\x01\n\x10\x41ttachmentCreate\x12:.pro.omni.oms.api.v1.stock.picking.AttachmentCreateRequest\x1a;.pro.omni.oms.api.v1.stock.picking.AttachmentCreateResponse"\x00\x12\x87\x01\n\x0e\x41ttachmentRead\x12\x38.pro.omni.oms.api.v1.stock.picking.AttachmentReadRequest\x1a\x39.pro.omni.oms.api.v1.stock.picking.AttachmentReadResponse"\x00\x12\x8d\x01\n\x10\x41ttachmentUpdate\x12:.pro.omni.oms.api.v1.stock.picking.AttachmentUpdateRequest\x1a;.pro.omni.oms.api.v1.stock.picking.AttachmentUpdateResponse"\x00\x12\x8d\x01\n\x10\x41ttachmentDelete\x12:.pro.omni.oms.api.v1.stock.picking.AttachmentDeleteRequest\x1a;.pro.omni.oms.api.v1.stock.picking.AttachmentDeleteResponse"\x00\x12\x84\x01\n\rCarrierCreate\x12\x37.pro.omni.oms.api.v1.stock.picking.CarrierCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.CarrierCreateResponse"\x00\x12~\n\x0b\x43\x61rrierRead\x12\x35.pro.omni.oms.api.v1.stock.picking.CarrierReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.picking.CarrierReadResponse"\x00\x12\x84\x01\n\rCarrierUpdate\x12\x37.pro.omni.oms.api.v1.stock.picking.CarrierUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.CarrierUpdateResponse"\x00\x12\x84\x01\n\rCarrierDelete\x12\x37.pro.omni.oms.api.v1.stock.picking.CarrierDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.picking.CarrierDeleteResponse"\x00\x12\x9f\x01\n\x16ProcurementGroupCreate\x12@.pro.omni.oms.api.v1.stock.picking.ProcurementGroupCreateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.ProcurementGroupCreateResponse"\x00\x12\x99\x01\n\x14ProcurementGroupRead\x12>.pro.omni.oms.api.v1.stock.picking.ProcurementGroupReadRequest\x1a?.pro.omni.oms.api.v1.stock.picking.ProcurementGroupReadResponse"\x00\x12\x9f\x01\n\x16ProcurementGroupUpdate\x12@.pro.omni.oms.api.v1.stock.picking.ProcurementGroupUpdateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.ProcurementGroupUpdateResponse"\x00\x12\x9f\x01\n\x16ProcurementGroupDelete\x12@.pro.omni.oms.api.v1.stock.picking.ProcurementGroupDeleteRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.ProcurementGroupDeleteResponse"\x00\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.picking_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _USER._serialized_start = 146
    _USER._serialized_end = 308
    _ATTACHMENT._serialized_start = 311
    _ATTACHMENT._serialized_end = 488
    _CARRIER._serialized_start = 491
    _CARRIER._serialized_end = 649
    _PROCUREMENTGROUP._serialized_start = 652
    _PROCUREMENTGROUP._serialized_end = 824
    _PICKING._serialized_start = 827
    _PICKING._serialized_end = 1510
    _USERCREATEREQUEST._serialized_start = 1512
    _USERCREATEREQUEST._serialized_end = 1622
    _USERCREATERESPONSE._serialized_start = 1625
    _USERCREATERESPONSE._serialized_end = 1775
    _USERREADREQUEST._serialized_start = 1778
    _USERREADREQUEST._serialized_end = 2143
    _USERREADRESPONSE._serialized_start = 2146
    _USERREADRESPONSE._serialized_end = 2354
    _USERUPDATEREQUEST._serialized_start = 2357
    _USERUPDATEREQUEST._serialized_end = 2487
    _USERUPDATERESPONSE._serialized_start = 2490
    _USERUPDATERESPONSE._serialized_end = 2640
    _USERDELETEREQUEST._serialized_start = 2642
    _USERDELETEREQUEST._serialized_end = 2729
    _USERDELETERESPONSE._serialized_start = 2731
    _USERDELETERESPONSE._serialized_end = 2826
    _ATTACHMENTCREATEREQUEST._serialized_start = 2828
    _ATTACHMENTCREATEREQUEST._serialized_end = 2953
    _ATTACHMENTCREATERESPONSE._serialized_start = 2956
    _ATTACHMENTCREATERESPONSE._serialized_end = 3124
    _ATTACHMENTREADREQUEST._serialized_start = 3127
    _ATTACHMENTREADREQUEST._serialized_end = 3498
    _ATTACHMENTREADRESPONSE._serialized_start = 3501
    _ATTACHMENTREADRESPONSE._serialized_end = 3727
    _ATTACHMENTUPDATEREQUEST._serialized_start = 3730
    _ATTACHMENTUPDATEREQUEST._serialized_end = 3878
    _ATTACHMENTUPDATERESPONSE._serialized_start = 3881
    _ATTACHMENTUPDATERESPONSE._serialized_end = 4049
    _ATTACHMENTDELETEREQUEST._serialized_start = 4051
    _ATTACHMENTDELETEREQUEST._serialized_end = 4144
    _ATTACHMENTDELETERESPONSE._serialized_start = 4146
    _ATTACHMENTDELETERESPONSE._serialized_end = 4247
    _CARRIERCREATEREQUEST._serialized_start = 4249
    _CARRIERCREATEREQUEST._serialized_end = 4355
    _CARRIERCREATERESPONSE._serialized_start = 4358
    _CARRIERCREATERESPONSE._serialized_end = 4517
    _CARRIERREADREQUEST._serialized_start = 4520
    _CARRIERREADREQUEST._serialized_end = 4888
    _CARRIERREADRESPONSE._serialized_start = 4891
    _CARRIERREADRESPONSE._serialized_end = 5108
    _CARRIERUPDATEREQUEST._serialized_start = 5111
    _CARRIERUPDATEREQUEST._serialized_end = 5250
    _CARRIERUPDATERESPONSE._serialized_start = 5253
    _CARRIERUPDATERESPONSE._serialized_end = 5412
    _CARRIERDELETEREQUEST._serialized_start = 5414
    _CARRIERDELETEREQUEST._serialized_end = 5504
    _CARRIERDELETERESPONSE._serialized_start = 5506
    _CARRIERDELETERESPONSE._serialized_end = 5604
    _PROCUREMENTGROUPCREATEREQUEST._serialized_start = 5606
    _PROCUREMENTGROUPCREATEREQUEST._serialized_end = 5726
    _PROCUREMENTGROUPCREATERESPONSE._serialized_start = 5729
    _PROCUREMENTGROUPCREATERESPONSE._serialized_end = 5916
    _PROCUREMENTGROUPREADREQUEST._serialized_start = 5919
    _PROCUREMENTGROUPREADREQUEST._serialized_end = 6296
    _PROCUREMENTGROUPREADRESPONSE._serialized_start = 6299
    _PROCUREMENTGROUPREADRESPONSE._serialized_end = 6544
    _PROCUREMENTGROUPUPDATEREQUEST._serialized_start = 6547
    _PROCUREMENTGROUPUPDATEREQUEST._serialized_end = 6714
    _PROCUREMENTGROUPUPDATERESPONSE._serialized_start = 6717
    _PROCUREMENTGROUPUPDATERESPONSE._serialized_end = 6904
    _PROCUREMENTGROUPDELETEREQUEST._serialized_start = 6906
    _PROCUREMENTGROUPDELETEREQUEST._serialized_end = 7005
    _PROCUREMENTGROUPDELETERESPONSE._serialized_start = 7007
    _PROCUREMENTGROUPDELETERESPONSE._serialized_end = 7114
    _PICKINGCREATEREQUEST._serialized_start = 7117
    _PICKINGCREATEREQUEST._serialized_end = 7748
    _PICKINGCREATERESPONSE._serialized_start = 7751
    _PICKINGCREATERESPONSE._serialized_end = 7910
    _PICKINGREADREQUEST._serialized_start = 7913
    _PICKINGREADREQUEST._serialized_end = 8281
    _PICKINGREADRESPONSE._serialized_start = 8284
    _PICKINGREADRESPONSE._serialized_end = 8501
    _PICKINGUPDATEREQUEST._serialized_start = 8504
    _PICKINGUPDATEREQUEST._serialized_end = 8643
    _PICKINGUPDATERESPONSE._serialized_start = 8646
    _PICKINGUPDATERESPONSE._serialized_end = 8805
    _PICKINGDELETEREQUEST._serialized_start = 8807
    _PICKINGDELETEREQUEST._serialized_end = 8897
    _PICKINGDELETERESPONSE._serialized_start = 8899
    _PICKINGDELETERESPONSE._serialized_end = 8997
    _PICKINGSERVICE._serialized_start = 9000
    _PICKINGSERVICE._serialized_end = 11788
# @@protoc_insertion_point(module_scope)
